@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hyperstitional-themes" "3.2.2"
+(define-package "hyperstitional-themes" "3.3"
   "Weird themes with incremental palettes."
   '((emacs "24.1"))
   :url "https://github.com/precompute/hyperstitional-themes"
-  :commit "cc8c33a23116ed112ef9ca3a973597f03dc41459"
-  :revdesc "cc8c33a23116"
+  :commit "acbff4befb65fd89fbd04d26630e25643c60229c"
+  :revdesc "acbff4befb65"
   :authors '(("precompute" . "git@precompute.net"))
   :maintainers '(("precompute" . "git@precompute.net")))
